<?php

App::uses('BuzzFacilitiesAppController', 'BuzzFacilities.Controller');

class FacilitiesController extends BuzzFacilitiesAppController {

	public $components = array(
		'BuzzAdverts.Adverts'
	);

	public function __construct($request = null, $response = null) {
		$this->adminActions[] = 'admin_adverts';

		$this->components['BuzzTranslate.Translation'] = array(
			'fields' => array(
				'name',
				'content' => array(
					'type' => 'html',
					'label' => __d('admin', 'Content')
				),
				'secondary_content' => array(
					'type' => 'html',
					'label' => __d('admin', 'Secondary Content')
				)
			)
		);

		parent::__construct($request, $response);
	}

	public function beforeFilter() {
		parent::beforeFilter();

		$this->Auth->allow(array(
			'index',
			'view'
		));
	}

/**
 * Facilities landing page
 *
 * @return void
 */
	public function index() {
		$facilities = $this->Facility->getListed();

		if (count($facilities) === 1 && !empty($facilities[0]['Facility']['id'])) {
			return $this->redirect([
				'controller' => 'facilities',
				'action' => 'view',
				$facilities[0]['Facility']['id']
			]);
		}

		if (Configure::check('BuzzFacilities.facilities_page_id') === true) {
			$data = $this->assignPage(Configure::read('BuzzFacilities.facilities_page_id'));
		}

		$this->set(compact('facilities'));
		$this->view = 'BuzzFacilities./Facilities/index';

		return;
	}

/**
 * Facility page
 *
 * @param int $id Facility ID
 * @return void
 */
	public function view($id) {
		$data = $this->Facility->readForView($id);

		// For BuzzGallery enabled sites set the gallery for the View.
		if (CakePlugin::loaded('BuzzGallery') === true && !empty($data['Facility']['gallery_id'])) {
			$this->set(
				'gallery',
				$this->Facility->Gallery->readForView($data['Facility']['gallery_id'])
			);
		}

		$this->set(compact('data'));
		$this->view = 'BuzzFacilities./Facilities/view';

		return;
	}

	public function admin_edit($id = null) {
		parent::admin_edit($id);
		$this->Adverts->setupAdvertAdminFields();
		$this->Translation->adminTranslationFormFields();
		return;
	}

/**
 * Admin form fields
 *
 * @return array
 */
	protected function _adminFormFields() {
		$fields = parent::_adminFormFields();

		$fields['Facility.content']['type'] = 'html';
		$fields['Facility.secondary_content']['type'] = 'html';

		// Localise labels.
		$fields['Facility.name']['label'] = __d('admin', 'Name');
		$fields['Facility.content']['label'] = __d('admin', 'Content');
		$fields['Facility.secondary_content']['label'] = __d('admin', 'Secondary Content');
		$fields['Facility.theme_id']['label'] = __d('admin', 'Theme');
		if (!empty($fields['Facility.gallery_id'])) {
			$fields['Facility.gallery_id']['label'] = __d('admin', 'Gallery');
		}
		$fields['Facility.video_url']['label'] = __d('admin', 'Video URL');

		return $fields;
	}

/**
 * Populate admin lookups
 *
 * @return void
 */
	protected function _adminPopulateLookups() {
		$Page = $this->{$this->modelClass};

		$this->set('themes', $Page->Theme->find('list'));

		if (CakePlugin::loaded('BuzzGallery') === true) {
			$this->set('galleries', $Page->Gallery->find('list'));
		}

		return;
	}

}
